package com.flyfish.framework.beans.meta;

import com.flyfish.framework.bean.Result;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.ClassUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * bean控制器，可以通过类直接返回bean信息
 *
 * @author wangyu
 */
@RestController
@RequestMapping("beans")
@Slf4j
public class BeanController {

    /**
     * 通过类标识返回bean信息
     *
     * @return 结果
     */
    @GetMapping("")
    public Result<List<BeanProperty>> beanInfo(String className) {
        try {
            return Result.ok(Arrays.stream(BeanUtils.getPropertyDescriptors(ClassUtils.getClass(className)))
                    .map(BeanProperty::form)
                    .collect(Collectors.toList()));
        } catch (ClassNotFoundException e) {
            log.error(e.getMessage(), e);
            return Result.error(e.getMessage());
        }
    }
}
