package com.flyfish.framework.beans.meta;

import lombok.Data;
import org.springframework.beans.BeanUtils;

import java.beans.PropertyDescriptor;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * bean的属性描述
 * 对应js的类型
 *
 * @author wangyu
 */
@Data
public class BeanProperty {

    // 属性名称
    private String name;

    // bean属性的类型，js类型
    private BeanPropertyType type;

    // 类型为object时，拥有子表单
    private List<BeanProperty> children;

    /**
     * 来自属性解释器构造
     * 支持对象嵌套
     *
     * @param descriptor 解释器
     * @return 结果
     */
    public static BeanProperty form(PropertyDescriptor descriptor) {
        BeanProperty property = new BeanProperty();
        property.setName(descriptor.getName());
        property.setType(BeanPropertyType.of(descriptor.getPropertyType()));
        if (property.getType() == BeanPropertyType.OBJECT) {
            List<BeanProperty> children = Arrays.stream(BeanUtils.getPropertyDescriptors(descriptor.getPropertyType()))
                    .map(BeanProperty::form)
                    .collect(Collectors.toList());
            property.setChildren(children);
        }
        return property;
    }
}
