package com.flyfish.framework.beans.meta;

import lombok.Getter;

import java.util.Arrays;
import java.util.Collection;
import java.util.Date;
import java.util.List;

/**
 * bean属性的类型
 * 包含java类型到js的映射
 * 我们通过类型自动解析bean的缺省控件，并自动映射
 * @author wangyu
 */
@Getter
public enum BeanPropertyType {

    STRING("String", CharSequence.class),
    NUMBER("Number", Number.class),
    BOOLEAN("Boolean", Boolean.class),
    DATE("Date", Date.class),
    ENUM("Enum", Enum.class),
    LIST("Array", Collection.class),
    OBJECT("Object", Object.class);

    BeanPropertyType(String name, Class<?> ...classes) {
        this.name = name;
        this.classes = Arrays.asList(classes);
    }

    private final String name;

    private final List<Class<?>> classes;

    public static BeanPropertyType of(Class<?> clazz) {
        for (BeanPropertyType type : values()) {
            if (type.classes.stream().anyMatch(item -> item.isAssignableFrom(clazz))) {
                return type;
            }
        }
        return null;
    }
}
